# Changelog

<!-- <START NEW CHANGELOG ENTRY> -->

## 3.0.0

([Full Changelog](https://github.com/holoviz/pyviz_comms/compare/v2.3.2...efc455dc826e73216e7da293d7cd2ee1155d3ada))

### Enhancements made

- Update to JupyterLab 4 [#114](https://github.com/holoviz/pyviz_comms/pull/114) ([@andrewfulton9](https://github.com/andrewfulton9))

### Other merged PRs

- pip downstream dependency to fix build error [#113](https://github.com/holoviz/pyviz_comms/pull/113) ([@andrewfulton9](https://github.com/andrewfulton9))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/holoviz/pyviz_comms/graphs/contributors?from=2023-06-15&to=2023-08-16&type=c))

[@andrewfulton9](https://github.com/search?q=repo%3Aholoviz%2Fpyviz_comms+involves%3Aandrewfulton9+updated%3A2023-06-15..2023-08-16&type=Issues) | [@philippjfr](https://github.com/search?q=repo%3Aholoviz%2Fpyviz_comms+involves%3Aphilippjfr+updated%3A2023-06-15..2023-08-16&type=Issues)

<!-- <END NEW CHANGELOG ENTRY> -->

## 3.0.0a3

No merged PRs

## 3.0.0a2

No merged PRs

## 3.0.0a1

([Full Changelog](https://github.com/holoviz/pyviz_comms/compare/v2.3.2...efc455dc826e73216e7da293d7cd2ee1155d3ada))

### Enhancements made

- Update to JupyterLab 4 [#114](https://github.com/holoviz/pyviz_comms/pull/114) ([@andrewfulton9](https://github.com/andrewfulton9))

### Other merged PRs

- pip downstream dependency to fix build error [#113](https://github.com/holoviz/pyviz_comms/pull/113) ([@andrewfulton9](https://github.com/andrewfulton9))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/holoviz/pyviz_comms/graphs/contributors?from=2023-06-15&to=2023-08-16&type=c))

[@andrewfulton9](https://github.com/search?q=repo%3Aholoviz%2Fpyviz_comms+involves%3Aandrewfulton9+updated%3A2023-06-15..2023-08-16&type=Issues) | [@philippjfr](https://github.com/search?q=repo%3Aholoviz%2Fpyviz_comms+involves%3Aphilippjfr+updated%3A2023-06-15..2023-08-16&type=Issues)
